<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/paprika/assets/logo.jpg */
class __TwigTemplate_4545a113b4bec47ea6b8b242e6d67ca6 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "\000JFIF\000\000`\000`\000\000\000hExif\000\000MM\000*\000\000\000\000\000\000\000\000\000\000\000>\000\000\000\000\000\000\000F(\000\000\000\000\000\000\0001\000\000\000\000\000\000\000N\000\000\000\000\000\000\000`\000\000\000\000\000\000`\000\000\000paint.net 4.2.12\000\000\000C\000\t\t\t





\t


\000C


















































\000\000!\000\000\000\000\000\000\000\000\000\000\000\000\t
\000\000\000\000}\000!1AQa\"q2#BR\$3br\t
%&'()*456789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000\000\000\000\000\000\t
\000\000\000w\000!1AQaq\"2B\t#3Rbr
\$4%&'()*56789:CDEFGHIJSTUVWXYZcdefghijstuvwxyz\000\000\000?\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\0004\000Q@\000f\0002:fE\000PE\000PE\000PE\000n\000g=(M\000PE\000PE\000PE\000PE\000PE\000P]gX|?]kVvv=!;\000I~9~\000r7y~\000
|7o{+VUZIcX!%NTxi,yrs|!e(ap39ߖ)VoFKI\000,V~j7'B4x9mԁ#\$%t,33pbf[Y5g^h8\\gɜJ~ZK`Ϗ?Sύ?N{\t|a|]P\\?chf9As&3O?.K3V:0i[{I?*9pp&<bB^{x7Sw{sg/Kg]zo9\000ċi]ɟ֝%}V`ʿZU\000yM[Ϯ>92jFNBPo|-z3Lg\000OƋ[yLF|<ʶ\tVaz}
4cV{Gpq_+!ZdT٦
+c
(\000
(\000
(o,?O\000-&2kԢ ma\$ǑHZETRv3~ƟpOmZNTx
u(Y[E#v&wumI|cb0r+syW&bxcA1|\\JPnQq\\ҋ֒W>\000X:=>'C?\t=bo[ܼ1fmǨ'5\000h?|#\000*񖗤_\\Y\t8]]\\F@=)3V2xhY4}mc?Goiq.#Z5Jbx9v|?c?B\000(\000(\000(\000(\000+\000kO#V7><˹!'#,rdjFU%SqdyN#?ΰeԅ8so7\000O
앦|'>3Ծj@ۭ}9\"?21<YH*XmG7A_xOz-Νr[j}F9F*U_⿴0qJ6O5٫u??8R>լԋZ2+9ۖIioH3[[GំuMKZLhsDusl,{W?O4S}/ĚXgkKq\$+q\000ÅʻfPr2ÿ'/҄ߵ_?>\$qmWPRV<ߵ{5jK/E}2~Cҿ%\000^!\000дގ!
+u!7\\3_˛8?\000GlK_VujC\000׏1XI.\\h7s7^c]gr_ؿo?k*:5w[K4錶zl.BUYOPd5>כupx[J%<,\\y)I4ԒֳI립sW[Wxkvw,|鲸YwCِv\$:SpyO:O}]d4p\\]i<E)F^r֯ϖq^B_T\$\000Q@\000Q@\t|y>Ki|gq:EºYIQwR#߶/ĿII麄sZy0f8v,\"[,@SKfʬ+]_3¾1aH҅SM+\$&vs ܁\000f~\000S\000}/GW{\000>#\000JQWPE\000PE\000PE\000PE\000P?x7g5/Ik=jZ\"FK1C8\000@?c\000/~_|A<,xG\"\\8luYG~sL^5ef~kfM\tm'R-J1VNDJzݿg/'3~?-_?\$֮g=QyM\"F'gYOx|kxеc
\$ՔKks0\000\000\$i@\000\000.]h
%xOLNwVzRPEAr8Z\\ɫuͪnW×G~jXd}NH:s 23/K7rks\000\0005oƚk/Nbک,m<I7.Y/J+*[%xcĞ#gY? VbVu.RR},Y]Dg1\000~Uỽk¾&\$iO-bAeI#g1V8;A}y}/F3fsrFQmqwi=M4k\0001KC\000igJ7\0005k\000<\000c\000\000C~\000c_\000j#n3_?s\000
~[M6R8-m&6nH@\000D cԿ[/ſG.'\\'{YI/V;kkˈ-!i%@Ƌv'\000M~\000Y\000__*ѭxR+iI%m**hbv223īzO+^ܫﺹyGe> qx&S|撄iK7nz'd~`|N\000D>,ݵ׊?kO[+f\"}s\\w~Z
Wu.{H#،W<2S՗\000|2˰+K*򂜟䜛~>/g7|9V^})dXcO27*cI\"G@HM\000~\000O3ͪcZ\\eFA E}fS`jFo߂n9s@ʫ`)\000c+SmK<лw]?\000Q;\000R?o߲~|\$z)\000'-RyJ#ʅՁ*X~ Sjh&:m
pY˚t%jjۚn7kT>E'n&_\000SG\"e\000W~ʟ\\ۧt-_\$'<y3#b;\\>uP9.Mw<A.BV*S+h仩6]u?qd/CNTi,
qsݨe\tîAᕕ!ۏ
g{|:)x\000/4Fe#DHm\000>9cZ|<\000\\ML0#l,kKe{)*<h֫i3q|yxAkSn:Ai
(!#LǐX
\000--xoxĲC`煎vH2q'Fwm/xOMҒ)Syi6&:nϷ\000w}W\000&x7&̟R䍥w3rNN^\000D/h}m!Uh0ePA:kf|gGkGX|xoL^[NuLRRV0I)\$c{x4<\000Лs\000f~\000S4\000\000C<\$\000|\000>#\000JD\000#yw}ABj{rǜGW\"p7/,[~8<aaIkzo莑FOJT02IcI& ͫakF\tY\000E}|ȸ)AUiI:1uj+H)gKYҟA[6oiV9<I*mTXs!GqS-/Wz/O/wL\$W1!\$Ղ#8ݐiO0p9<kMNow5u^
<B)*<
?z4۽yj5/6J2^\000H\000oxZ-?ēB>[\"
*\000\000o5_
ןHru˫wFU\"_[2Oc>gSC\"\000ۚw\000\000]oi?n9#'K]/y3­k1 y'][uu6kr\\8[⎏?\000<tƗ|X`һ4oQ^Q@\000Q@\000Q@\000rm`[<-%<'ɸdc>аupNsi߉}#:yhZ\000))\000xo\0004>z{jA'B[\\L57M+uݿj𽿛A\000&~Q\000_ռ{E~-xhmVl(\000dۈ9^o9}Nۛv?Q!)[a/{:mGŚG}WRǮZY[LE1[޿=)NVS:@l?\tr]4>OY4-]?Jߋvt>\t׷-:'BI 4w,\000NAЊs3z\000IGGXF9t%\000Z7
aYIauZkU kx|MyOxQֵ}B_2Tov闑f8Ê1ȥZm߂8\"d(ќե%i]'ek_cO\"oƿ?ǽώ|;=ÏMyqT/pZE\$
ґvn\000:>D<\tB5׾-nLT~1/zWdbJ4Zߕk㇊2̱ٱp~4iF4c'\000I6?g4zީ\$jRJo\tDQ\\?\000\000^|oKhZn\$O-{w6:dA\tȐI-L-KMy~W,,]zM7N<Γmuu^ּq\000>kW:.;ش8=7ھ/%\"k\$G*x뵭,nkT?\000=\000۫N\\4\000zc.Uc\000,T*Ma`a)mG\000qZ\$<ލ)JVn\000'\000|>E׼yzզqz
ӺgBGF^Fğ~%ڤzφhc
d\$RH\$\\vx)c
ѯ>LX<zqU!52M\$lw;
߶d\0005YD-b{e&5>>uA_0\000E\000>3LֿZUi_>#H,ҼQ\000s~\000|G3?> m|6E
/\$6DVv 8
#
}dqߵv h{qiȾƒc}AҵɲUSI;/_<u.ZHIIwqI[^i5-^-;\000\0001[_j:AH|pm|;wlܜg5J&\000a_ug=WK7U&V^\000'˟+59EҾ^\\XWZ^yoj,VqLꛈ\$8iSTzE_kʥTm]6\\yǺh,dD=^BvW/#'j/G~6m_.߾o+s82n^8:rskϫ]?OCN50~\t;ޣN4iy՟~wS{GtI=: cB\"\000\000\000
?\000=?||btiWdy& ]6ag?c4qcSkc^<8s8N･i[Z_MOz]Up(`̷F'񯌿_ٛZ>+_˥_R-VݦHwY7Ƀxs,._8m=]g^+\\+^jHiSpd~t\\v?K\000KOO'߉\"{Bo
̍Wif0n'&>ˊ7\0003N˱]zNi
+(\000(\000(o\000~
~)x^X56Դ;eUV_??_|3E6MoGȷ rI!Ty,ĕ\0003||*cRywk^T#XEFU1mZT-\000h'=ZنFc5^A{`3vB
^;>\t_[_><7·WK^&UUYRG1]X\\N19%m:#Ŝ-RV2Φa9:?6wDO#^-\0004*{>J%,gxIR2\000i\t#\000#yO7Ha{=7Zn\"k\$|T(dvQ򳪀9O(^V~^\0009bx#{Ex^J
;;VZK?gO'M?xP-q>u
=-,lf+8YʧfrpwaVv_K-}[x~&+3Sb
qmEj{mv#\000/W7t5iE2u}28!Y8ϵ*/O%r_5UZmBO\000PY\000z/ >s\000wPh̷1?
yp={WQ̶߫?3YXhԥGG*p)[\$F|?º=3Zi}+
__Y\000,ů/P,k[nF1b\" T[l,zz7xBJ2U64[ޜV?0tm;&gK>)\0005Y[%f%6,\000I к
.'+v1HFkpna^?ğ<1,02)SmGd`vg
k/\t?m.\000DU?\000If~0IK5\000ԚG_kZƩ\000ͧhF'(p%\000:
(0c2F1_xgU\000kx}i|7[<ϑ)s__BYx9Geߧ55y*
K-5X<P\0005V(o)_!\0002u\000_?hӔ?5TK}U\000xsMտnokw\$_Ë,ٗ>[e̹c_\\7VY?RbޑI/NV\0006:S'MV9kO\000Qm}\000!\000s/?./5}\000#j/\000LUvm!Tyt.ٔ2=FA}\000;\000 6QZߴb=3P^s©ϕ!mebqWaNK=?ߋ\\320๦y~ly#2H\000U\$~H7VQo-eXEl}i\">2!PO,¦SvKs{[W[U0H\\^26X6m\$WO_?g=exI/^maHVf\t73^_\000\000Zkͮ~\\jsIk\tH˪pLXt8yb#]ݻ^۟ۙǊ>QEuL!p|m('ʹc{VN1%^\000\000\0008.\000*jPE\000PE\000P^?vʶɮz,OL^53Qt5
!摏3VKw䚕v}\000\000y{B_>?;ʑ%lq?_o[ڗ_&ubu-Jc\$=@\000\000\000\000\000W_r~\000F<,~)xR:!+ߓIu\000;ƹkǁ\$xWSO[f71g>[4BDl_E~_o7B~0Nǟ\$L!Pvmy3;jfZWMǊ\\yxWŹ]KL59FJRs]S^I6~_j
t>\t׷-:+|\000#\000a[{\000#\000IG}\000'\000R}O+\000S~~1h*D&ync_+őU\000_D
cٍJk5#H\"G3|z^H^[ViYay[K(\$#s\000~^x?kZ?G|+snf#Y\$PRs3c8乮\tԕﵻώxKPb#N>k
\\\\줗2k7z܇s\"B\000v&Z\000K?|^1/~yk&K^47@'Y]JNߴ[˵veuUρOhmt}|&\"\\'RUm_Ss<
=ٷR3Vj[9\\9ity_? ⿎uo_uMs\\%5O4'\000\000`\000\0008q\000%BqX񭉭h)wrvr-][\000o\000ds_NZkS&\tt{>sFMކxk(o)OEi7e\"xg;}!3t\tJ]MNK)Gl?\000*¯՟?J;U\000/ \000>??_
\000h?\000_+\000믣=T \000~\000ؙs\000fω0k'<Rdd2{R(e Q9ͣgٸx7\t^F'\000\000ًM?xO>iBiMn<`T3\0000àpkN#_kG31u^&XLLaJ2mݸH(\000ۧsmO߳7wy,߾ᵺ:1X<؜_6\\IkuG\$nRH\\28 3C|~ɑ8✢*5hԂ\000uIA/(?P\000Pchs⯀<Wg=GV/B2qPy%\000f\"\\>s`}\000mM(m)\"uvm̖Z|>jHqBOͰTG/yEn?%?x4B,y<\$ӯ9\$'ޏmO3ֿo!'oka/'?K7?
}uE}v\000Q@\000Q@\000PFF
\000c|A?%Xs5o4{K;W[DeXE~~_o75ݏ\000i<^յ1w,˝saNM+ҟG_oqؼs'6!FJi9rNZvԔI٥s\000|G|5]>:fMA۹VIj6y>ьW_'՟TDFoA5G݅4䂲mtrw^^\000\000t~_ƣZ,huu?Am3ܩǭ|37
'xOoto6.vqA_x^a*еn\$y#='Ԝ2%}7?y'\\SpGO7|X{[E[o]DZWs;deeB\\Ù`aeEuOGeXӏ<cxԎ夗Q̕?.|_\000,\000xSZJ֢Y
Ǩh%hed}{[\000|m_,Uhjv~K:\\79XE07!FJ)믙şIJ-W[8pydm%hZMݫ-=
\000mFOk_Lt\0003\0000y
g;qֽA~Jÿm4n<Eq
'R*R\$umhrՅ*;rf#Ǿ\t㜫`}'?z\tGܯNRכC.H?fo#u8-<;
;Vu@\000a\"Pc42@
R6UYYҽ+ix709?\"9S{yFў+!A՛LpmAC.\000i\000\000W~n1ߵ?4h1Mo.Q{#ܩ\000f7YFWt8A_xK^>IkG7\$Koe~|
mU?xtE-b3v<ĳ9\${\000(>5~?~.#Ih&񦥩mu1k.ôaھ90в}v0x#S|_<C)X;1Rnr&կE%Y~\$AL.jt`\\HgkiFWhs4Փ`p*K^o3jLo{)BW:wl|\000\000w~ѿj\000li>O/nT\000R־\000<[w7zͷ\"xyG2Do#\t{^
fUO\tߩ9-yI+}\000\000c_ů%5ɬյqlV6w\000f? {COJߎ4WRk[E,WgPw43<D-x//!p\\þ_iUq6Z{w?o'%XpG~1~\000oG\t~ WcbXi-de-CPʽTgmLN}{=\000C?\000R|3MLϙӳPW|pvk~/\000Yh/=[`X7gLm9Q^\000%\000^|z֣AZ֛y7Yk5外d\"wlX:+ɥ⥗KQ{Y_6CnĬ'P*U):
/IJNQnIowK\000\000j\000\000̳Ic\tm0/6\000mox㏊tټqqۘ=.F|np7mo@S8%|Ãd?nROmi|[MdUe^\$y>e˖1_j\000F#Fo\000u(~þj(A6oG&*gEzORVq|||H,>]{Oi
ѨࢹT*G~g䏠(?B\000(\000(\000(\000(\000(\000(\000+*_?%5|gOɟM_YeG\000NDik\000\0000\000a]g\000N3%i\000&ڇ\000M>͢@?P
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000
(\000K\t<ASڿ|K,g;OpjjB5)Kf~;q>:S}W4Zꮶ>:no?Nff/_}77`sKkwͺiW\\qOVu)'{[WGsO-'MҌ,_2RKIz%\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@\000Q@";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/paprika/assets/logo.jpg";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/paprika/assets/logo.jpg", "/var/www/html/production-demo/themes/paprika/assets/logo.jpg");
    }
}
